@@ -54,7 +54,7 @@ NotificationClient.prototype = {
       iconButton.className = 'notification-RELEASE_NOTES-button';
 
       var bellIcon = document.createElement('i');
-      bellIcon.className = 'fas fa-bell';
+      bellIcon.className = 'fas fa-bell-on';
       bellIcon.style.cssText = "font-size: 16px; color: #ff4a3f;";
 
       iconButton.appendChild(bellIcon);
@@ -112,8 +112,8 @@ NotificationClient.prototype = {
           that.dismissNotification(true, 'OK');
         };
         exitIcon = document.createElement('i');
-        exitIcon.className = 'fas fa-times';
-        exitIcon.style.cssText = "font-size: 16px; color: #636363;";
+        exitIcon.className = 'fal fa-times';
+        exitIcon.style.cssText = "font-size: 24px; color: #636363;";
         exitButton.appendChild(exitIcon);
 
         var title = document.createElement('h1');
